import socket
import time
import json

UDP_IP = "192.168.4.1"
UDP_PORT = 8888
drone_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

COMMAND_TIMEOUT = 0.5
ACTION_TIMEOUT = 5.0
RECEIVE_BUFF_SIZE = 1024


def transmit(msg):
    """
    Send data packet through UDP port
    """
    drone_socket.sendto(msg, (UDP_IP, UDP_PORT))


def get_message_confirmation(timeout=COMMAND_TIMEOUT):
    """
    Get confirmation on data packet received by drone

    Args:
    timeout (float): time duration (in seconds) to wait for a confirmation message. If a confirmation not received, code execution will be suspended for this period

    Returns:
        confirmation status
        Note: currently always return 1
    """
    start_time = time.time()

    while time.time() - start_time < timeout:
        pass  # TODO: add real while loop

        # data, addr = drone_socket.recvfrom(RECEIVE_BUFF_SIZE)

        # temp_data = json.loads(data)
        # print("Command reply:")
        # print(temp_data)

        # if temp_data["validated"] == 1:
        #     return 1

    # return 0

    return 1  # TODO: add real confirmation parameters


def get_action_confirmation(timeout=ACTION_TIMEOUT):
    """
    Get confirmation on requested action executed by the drone

    Args:
    timeout (float): time duration (in seconds) to wait for a confirmation message. If a confirmation not received, code execution will be suspended for this period

    Returns:
        confirmation status
        Note: currently always return 1
    """
    start_time = time.time()

    while time.time() - start_time < timeout:
        pass  # TODO: add real while loop

        # data, addr = drone_socket.recvfrom(RECEIVE_BUFF_SIZE)

        # temp_data = json.loads(data)
        # print("Action reply: ")
        # print(temp_data)

        # if temp_data["act_done"] == 1:
        #     return 1

    # return 0
    return 1  # TODO: add real confirmation parameters


def packet_monitor(duration=0.1):
    """
    TODO
    """
    start_time = time.time()
    while time.time() - start_time < duration:
        data, addr = drone_socket.recvfrom(RECEIVE_BUFF_SIZE)

        temp_data = json.loads(data)
        print("Received: ")
        print(temp_data)

    return 0
