import subprocess
import sys
import importlib.util

# List of packages to be installed for X-Fly Python SDK
REQUIRED_PACKAGES = ["json", "time", "sys", "pygame", "socket"]


def is_package_installed(package):
    """
    Check if a package is already installed

    Args:
        package (REQUIRED_PACKAGES): package name to check availability on the system

    Returns:
        Package availability status
    """
    return importlib.util.find_spec(package) is not None


def install_package(package):
    """
    Install the package using pip

    Args:
        package (REQUIRED_PACKAGES): package name to install
    """
    try:
        subprocess.check_call([sys.executable, "-m", "pip", "install", package])
        print(f"Successfully installed {package}")
    except subprocess.CalledProcessError:
        print(f"Failed to install {package}")


def main():
    for package in REQUIRED_PACKAGES:
        if is_package_installed(package):
            print(f"{package} is already installed.")
        else:
            print(f"{package} is not installed. Installing...")
            install_package(package)


if __name__ == "__main__":
    main()
