PID_TYPES = {"Roll", "Pitch", "Yaw", "YawRate", "AltHoldRate", "AltHold"}


# ------------------------------------------#
# Validation for thrust values
# ------------------------------------------#
def thrust(thrust):
    """
    validate thrust value

    Args:
        thrust (int): thrust value to validate. Range is (0%)-(100%)

    Returns:
        Validation status of the given value
    """
    if type(thrust) is int:
        if thrust < 0 or thrust > 100:
            print("Thrust should be between 0-100")
            return 0

        else:
            return 1

    else:
        print("Thrust should be an Integer")
        return 0


# ------------------------------------------#
# Validation for angle values
# ------------------------------------------#
def euler(angle):
    """
    Validate euler angle values

    Args:
     angle (int): angle to validate. Range is (-30°)-(+30°)

    Returns:
        Validation status of the given value
    """
    if type(angle) is int:
        if angle < -30 or angle > 30:
            print("Roll and Pitch should be between -30 and +30")
            return 0

        else:
            return 1

    else:
        print("Roll and Pitch should be Integers")
        return 0


# ------------------------------------------#
# Validation for yaw rate values
# ------------------------------------------#
def yaw_rate(yaw_rate):
    """
    Validate yaw rate values

    Args:
     yaw_rate (int): yaw rate to validate. Range is (-100)-(+100)

    Returns:
        Validation status of the given value
    """
    if type(yaw_rate) is int:
        if yaw_rate < -100 or yaw_rate > 100:
            print("Yaw Rate should be between -100 and 100")
            return 0

        else:
            return 1

    else:
        print("Yaw Rate should be an Integer")
        return 0


# ------------------------------------------#
# Validation for height values
# ------------------------------------------#
def height(height):
    """
    Validate height values

    Args:
        height (float): height to validate. Range is (0.0m)-(2.0m)

    Returns:
        Validation status of the given value
    """
    if type(height) is float:
        if height < 0.0 or height > 2.0:
            print("Height should be between 0.1-2.0")
            return 0

        else:
            return 1

    else:
        print("Height should be a Float")
        return 0


# ------------------------------------------#
# Validation for PID values (positive float)
# ------------------------------------------#
def positive_float(number):
    """
    Validate PID values

    Args:
        number (float): PID value to validate

    Returns:
        Validation status of the given value
    """
    if type(number) is float and number > 0.0:
        return 1

    else:
        print("PID value must be a positive float")
        return 0


# ------------------------------------------#
# Validation for PID type
# ------------------------------------------#
def pid_type(type):
    """
    Validate PID types

    Args:
        type (PID_TYPES): PID type to validate

    Returns:
        Validation status of the given value
    """
    if type in PID_TYPES:
        return 1

    else:
        print("Invalid PID Type")
        return 0


# ------------------------------------------#
# Validation for velocity values
# ------------------------------------------#
def movement_velocity(vel):
    """
    Validate velocity values

    Args:
        vel (int/ float): velocity value to validate

    Returns:
        Validation status of the given value
    """
    if type(vel) is float or type(vel) is int:
        return 1

    else:
        print("Velocity value should be a number")
        return 0
